package ru.rell.controller;

import io.swagger.v3.oas.annotations.Operation;
import lombok.RequiredArgsConstructor;
import org.springframework.core.io.Resource;
import org.springframework.core.io.ByteArrayResource;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;
import ru.rell.handler.exception.CustomException;

import java.io.IOException;

@RestController
@RequestMapping("api/v1/recognize")
@RequiredArgsConstructor
public class RecognizeController {

    @Operation(
            summary = "Распознование текста из фаила вернет txt; attachment; filename= имя фаила",
            description = "Распознование текста из фаила вернет txt; attachment; filename= имя фаила"
    )
    @PostMapping(produces = MediaType.MULTIPART_FORM_DATA_VALUE)
    public ResponseEntity<Resource> recognize(@RequestPart("file") MultipartFile file){
        if (file.isEmpty()) {
            return ResponseEntity.badRequest().build();
        }

        ByteArrayResource resource = null;
        try {
            resource = new ByteArrayResource(file.getBytes());
        } catch (IOException e) {
            throw new CustomException(e.getMessage(),e);
        }
        resource.getFilename();

        return ResponseEntity.ok()
                .contentType(MediaType.APPLICATION_OCTET_STREAM)
                .header("Content-Disposition", "attachment; filename=\"" + file.getOriginalFilename() + "\"")
                .body(resource);
    }
}
